# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.sound_feature_set import SoundFeatureSet  # noqa: E501
from mozart_api.rest import ApiException


class TestSoundFeatureSet(unittest.TestCase):
    """SoundFeatureSet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SoundFeatureSet
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.sound_feature_set.SoundFeatureSet()  # noqa: E501
        if include_optional:
            return SoundFeatureSet(
                ambience=null,
                balance=null,
                bass=null,
                bass_management=null,
                compression=null,
                directivity=null,
                fader=null,
                room_compensation=null,
                spatial_envelopment=null,
                spatial_height=null,
                spatial_processing=null,
                spatial_surround=null,
                spatial_width=null,
                speech_enhance=null,
                tone_touch_x=null,
                tone_touch_y=null,
                treble=null,
            )
        else:
            return SoundFeatureSet()

    def testSoundFeatureSet(self):
        """Test SoundFeatureSet"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Literal, Optional


from mozart_api.configuration import Configuration


class WebsocketNotificationTag(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"value": "str"}

    attribute_map = {"value": "value"}

    def __init__(
        self,
        value: Optional["WebsocketNotificationTag.LTypeValue"] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """WebsocketNotificationTag - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._value = None
        self.discriminator = None

        if value is not None:
            self.value = value

    LTypeValue = Literal[
        "configuration",
        "uri",
        "generatorSettings",
        "lineInSettings",
        "bluetoothDevices",
        "remoteControlDevices",
        "secondariesList",
        "queueHasBeenChanged",
        "endOfQueueHasBeenReached",
        "beolinkPeers",
        "beolinkListeners",
        "beolinkAvailableListeners",
        "bluetoothPairingStateChanged",
        "outputsChanged",
        "speakerGroupOverviewChanged",
        "remoteMenuChanged",
        "proximityPresenceDetected",
        "proximityPresenceNotDetected",
    ]

    @property
    def value(self):
        # type: () -> 'WebsocketNotificationTag.LTypeValue'
        """Gets the value of this WebsocketNotificationTag.  # noqa: E501


        :return: The value of this WebsocketNotificationTag.  # noqa: E501
        :rtype: 'WebsocketNotificationTag.LTypeValue'
        """
        return self._value

    @value.setter
    def value(self, value):
        # type: ('WebsocketNotificationTag.LTypeValue') -> None
        """Sets the value of this WebsocketNotificationTag.


        :param value: The value of this WebsocketNotificationTag.  # noqa: E501
        :type value: 'WebsocketNotificationTag.LTypeValue'
        :rtype: None
        """
        allowed_values = [
            "configuration",
            "uri",
            "generatorSettings",
            "lineInSettings",
            "bluetoothDevices",
            "remoteControlDevices",
            "secondariesList",
            "queueHasBeenChanged",
            "endOfQueueHasBeenReached",
            "beolinkPeers",
            "beolinkListeners",
            "beolinkAvailableListeners",
            "bluetoothPairingStateChanged",
            "outputsChanged",
            "speakerGroupOverviewChanged",
            "remoteMenuChanged",
            "proximityPresenceDetected",
            "proximityPresenceNotDetected",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and value not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `value` ({0}), must be one of {1}".format(  # noqa: E501
                    value, allowed_values
                )
            )

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebsocketNotificationTag):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebsocketNotificationTag):
            return True

        return self.to_dict() != other.to_dict()



"""Helper classes for using auto-generated API."""
# pylint: disable=not-callable line-too-long too-many-instance-attributes too-many-public-methods

import asyncio
import json
import logging
import re
from dataclasses import dataclass
from datetime import time
from threading import Thread
from typing import Union

from aiohttp import ClientSession
from aiohttp.client_exceptions import ClientConnectorError
from inflection import underscore
from mozart_api.api.mozart_api import MozartApi
from mozart_api.api_client import ApiClient
from mozart_api.configuration import Configuration

RECONNECT_INTERVAL: float = 15.0

logger = logging.getLogger(__name__)


@dataclass
class WebsocketResponse:
    """Class for mimicing the needed RESTResponse structure for deserialize()"""

    data: str


def refactor_name(notification_type: str) -> str:
    """Remove WebSocketEvent prefix from string and convert to snake_case."""
    return underscore(notification_type.removeprefix("WebSocketEvent"))


def time_to_seconds(time_object: time) -> int:
    """Convert time object to number of seconds."""
    time_in_seconds = (
        (time_object.hour * 60 * 60) + (time_object.minute * 60) + time_object.second
    )

    return time_in_seconds


def check_valid_jid(jid: str) -> bool:
    """Check if a JID is valid."""
    pattern = re.compile(r"(^\d{4})[.](\d{7})[.](\d{8})(@products\.bang-olufsen\.com)$")

    if pattern.fullmatch(jid) is not None:
        return True

    return False


class MozartClient(MozartApi):
    """User friendly setup for Mozart device."""

    def __init__(
        self,
        host: str,
        websocket_reconnect: bool = False,
        websocket_reconnect_interval: float = RECONNECT_INTERVAL,
    ) -> None:
        """Initialize Mozart device."""
        self.host: str = host
        self.websocket_connected: bool = False
        self.websocket_reconnect: bool = websocket_reconnect
        self.websocket_reconnect_interval: float = websocket_reconnect_interval

        self.websocket_thread: Union[Thread, None] = None
        self.websocket_remote_thread: Union[Thread, None] = None
        self.websocket_active: bool = False

        self._on_connection_lost = None
        self._on_connection = None

        self._on_all_notifications = None
        self._on_all_notifications_raw = None

        self._on_active_hdmi_input_signal_notification = None
        self._on_active_listening_mode_notification = None
        self._on_active_speaker_group_notification = None
        self._on_alarm_timer_notification = None
        self._on_alarm_triggered_notification = None
        self._on_battery_notification = None
        self._on_beo_remote_button_notification = None
        self._on_beolink_experiences_result_notification = None
        self._on_beolink_join_result_notification = None
        self._on_button_notification = None
        self._on_curtains_notification = None
        self._on_hdmi_video_format_signal_notification = None
        self._on_notification_notification = None
        self._on_playback_error_notification = None
        self._on_playback_metadata_notification = None
        self._on_playback_progress_notification = None
        self._on_playback_source_notification = None
        self._on_playback_state_notification = None
        self._on_power_state_notification = None
        self._on_puc_install_remote_id_status_notification = None
        self._on_role_notification = None
        self._on_room_compensation_current_measurement_event_notification = None
        self._on_room_compensation_state_notification = None
        self._on_software_update_state_notification = None
        self._on_sound_settings_notification = None
        self._on_source_change_notification = None
        self._on_speaker_group_changed_notification = None
        self._on_stand_connected_notification = None
        self._on_stand_position_notification = None
        self._on_tv_info_notification = None
        self._on_volume_notification = None
        self._on_wisa_out_state_notification = None

        # Configure MozartApi object.
        configuration = Configuration(host=self.host)
        configuration.verify_ssl = False

        super().__init__(ApiClient(configuration))

    def connect_notifications(self, remote_control=False) -> None:
        """Start the WebSocket listener process."""
        self.websocket_active = True

        # Start main WebSocket listener.
        self.websocket_thread = Thread(
            target=self._start_websocket_listener,
            args=(f"ws://{self.host}:9339/",),
        )
        self.websocket_thread.start()

        # Start another WebSocket listener for remote control events.
        if remote_control:
            self.websocket_remote_thread = Thread(
                target=self._start_websocket_listener,
                args=(f"ws://{self.host}:9339/remoteControl",),
            )
            self.websocket_remote_thread.start()

    def disconnect_notifications(self) -> None:
        """Stop the WebSocket listener process. Relies on an asyncio.wait_for timeout so may be slow."""
        self.websocket_active = False

        # Stop notification listener if alive
        if self.websocket_thread is not None:
            self.websocket_thread.join()

        # Stop remote notification listener if alive
        if self.websocket_remote_thread is not None:
            self.websocket_remote_thread.join()

        self.websocket_connected = False

    def _start_websocket_listener(self, host: str) -> None:
        """Start the async WebSocket listener."""
        asyncio.run(self._websocket_listener(host))

    async def _websocket_listener(self, host: str) -> None:
        """WebSocket listener."""

        while True:
            try:
                async with ClientSession() as session:
                    async with session.ws_connect(
                        url=host, heartbeat=15.0
                    ) as websocket:
                        if self._on_connection and not self.websocket_connected:
                            self.websocket_connected = True
                            self._on_connection()
                        else:
                            self.websocket_connected = True

                        while self.websocket_active:
                            # Add asyncio.wait_for to check if thread should be closed when no notifications are received.
                            try:
                                # Receive JSON in order to get the Websocket notification name for deserialization
                                notification = await asyncio.wait_for(
                                    websocket.receive_json(),
                                    timeout=5.0,
                                )

                                # Ensure that any notifications received after the disconnect command has been executed are not processed
                                if not self.websocket_active:
                                    return

                                self._on_message(notification)

                            except asyncio.TimeoutError:
                                pass
                        return

            except (ClientConnectorError, TypeError) as error:
                if self.websocket_connected:
                    self.websocket_connected = False
                    if self._on_connection_lost:
                        self._on_connection_lost()

                if not self.websocket_reconnect:
                    logger.error("%s : %s", host, error)
                    return

                await asyncio.sleep(self.websocket_reconnect_interval)

    def _on_message(self, notification) -> None:
        """Handle WebSocket notifications."""

        # Get the object type and deserialized object.
        try:
            notification_type = notification["eventType"]

            deserialized_data = self.api_client.deserialize(
                WebsocketResponse(json.dumps(notification)), notification_type
            ).event_data

            refactored_type = refactor_name(notification_type)

        except (ValueError, AttributeError) as error:
            logger.error(
                "Error deserializing WebSocket notification %s error %s",
                notification_type,
                error,
            )
            return

        # Ensure that only valid notifications trigger callbacks
        if deserialized_data is None:
            return

        # Handle all notifications if defined
        if self._on_all_notifications:
            self._on_all_notifications(deserialized_data, refactored_type)

        if self._on_all_notifications_raw:
            self._on_all_notifications_raw(notification)

        # Handle specific notifications if defined
        {
            "WebSocketEventActiveHdmiInputSignal": lambda notification: self._on_active_hdmi_input_signal_notification(
                notification
            )
            if self._on_active_hdmi_input_signal_notification
            else None,
            "WebSocketEventActiveListeningMode": lambda notification: self._on_active_listening_mode_notification(
                notification
            )
            if self._on_active_listening_mode_notification
            else None,
            "WebSocketEventActiveSpeakerGroup": lambda notification: self._on_active_speaker_group_notification(
                notification
            )
            if self._on_active_speaker_group_notification
            else None,
            "WebSocketEventAlarmTimer": lambda notification: self._on_alarm_timer_notification(
                notification
            )
            if self._on_alarm_timer_notification
            else None,
            "WebSocketEventAlarmTriggered": lambda notification: self._on_alarm_triggered_notification(
                notification
            )
            if self._on_alarm_triggered_notification
            else None,
            "WebSocketEventBattery": lambda notification: self._on_battery_notification(
                notification
            )
            if self._on_battery_notification
            else None,
            "WebSocketEventBeoRemoteButton": lambda notification: self._on_beo_remote_button_notification(
                notification
            )
            if self._on_beo_remote_button_notification
            else None,
            "WebSocketEventBeolinkExperiencesResult": lambda notification: self._on_beolink_experiences_result_notification(
                notification
            )
            if self._on_beolink_experiences_result_notification
            else None,
            "WebSocketEventBeolinkJoinResult": lambda notification: self._on_beolink_join_result_notification(
                notification
            )
            if self._on_beolink_join_result_notification
            else None,
            "WebSocketEventButton": lambda notification: self._on_button_notification(
                notification
            )
            if self._on_button_notification
            else None,
            "WebSocketEventCurtains": lambda notification: self._on_curtains_notification(
                notification
            )
            if self._on_curtains_notification
            else None,
            "WebSocketEventHdmiVideoFormatSignal": lambda notification: self._on_hdmi_video_format_signal_notification(
                notification
            )
            if self._on_hdmi_video_format_signal_notification
            else None,
            "WebSocketEventNotification": lambda notification: self._on_notification_notification(
                notification
            )
            if self._on_notification_notification
            else None,
            "WebSocketEventPlaybackError": lambda notification: self._on_playback_error_notification(
                notification
            )
            if self._on_playback_error_notification
            else None,
            "WebSocketEventPlaybackMetadata": lambda notification: self._on_playback_metadata_notification(
                notification
            )
            if self._on_playback_metadata_notification
            else None,
            "WebSocketEventPlaybackProgress": lambda notification: self._on_playback_progress_notification(
                notification
            )
            if self._on_playback_progress_notification
            else None,
            "WebSocketEventPlaybackSource": lambda notification: self._on_playback_source_notification(
                notification
            )
            if self._on_playback_source_notification
            else None,
            "WebSocketEventPlaybackState": lambda notification: self._on_playback_state_notification(
                notification
            )
            if self._on_playback_state_notification
            else None,
            "WebSocketEventPowerState": lambda notification: self._on_power_state_notification(
                notification
            )
            if self._on_power_state_notification
            else None,
            "WebSocketEventPucInstallRemoteIdStatus": lambda notification: self._on_puc_install_remote_id_status_notification(
                notification
            )
            if self._on_puc_install_remote_id_status_notification
            else None,
            "WebSocketEventRole": lambda notification: self._on_role_notification(
                notification
            )
            if self._on_role_notification
            else None,
            "WebSocketEventRoomCompensationCurrentMeasurementEvent": lambda notification: self._on_room_compensation_current_measurement_event_notification(
                notification
            )
            if self._on_room_compensation_current_measurement_event_notification
            else None,
            "WebSocketEventRoomCompensationState": lambda notification: self._on_room_compensation_state_notification(
                notification
            )
            if self._on_room_compensation_state_notification
            else None,
            "WebSocketEventSoftwareUpdateState": lambda notification: self._on_software_update_state_notification(
                notification
            )
            if self._on_software_update_state_notification
            else None,
            "WebSocketEventSoundSettings": lambda notification: self._on_sound_settings_notification(
                notification
            )
            if self._on_sound_settings_notification
            else None,
            "WebSocketEventSourceChange": lambda notification: self._on_source_change_notification(
                notification
            )
            if self._on_source_change_notification
            else None,
            "WebSocketEventSpeakerGroupChanged": lambda notification: self._on_speaker_group_changed_notification(
                notification
            )
            if self._on_speaker_group_changed_notification
            else None,
            "WebSocketEventStandConnected": lambda notification: self._on_stand_connected_notification(
                notification
            )
            if self._on_stand_connected_notification
            else None,
            "WebSocketEventStandPosition": lambda notification: self._on_stand_position_notification(
                notification
            )
            if self._on_stand_position_notification
            else None,
            "WebSocketEventTvInfo": lambda notification: self._on_tv_info_notification(
                notification
            )
            if self._on_tv_info_notification
            else None,
            "WebSocketEventVolume": lambda notification: self._on_volume_notification(
                notification
            )
            if self._on_volume_notification
            else None,
            "WebSocketEventWisaOutState": lambda notification: self._on_wisa_out_state_notification(
                notification
            )
            if self._on_wisa_out_state_notification
            else None,
        }[notification_type](deserialized_data)

    def get_on_connection_lost(self, on_connection_lost) -> None:
        """Callback for WebSocket connection lost."""
        self._on_connection_lost = on_connection_lost

    def get_on_connection(self, on_connection) -> None:
        """Callback for WebSocket connection."""
        self._on_connection = on_connection

    def get_all_notifications(self, on_all_notifications) -> None:
        """Callback for all notifications."""
        self._on_all_notifications = on_all_notifications

    def get_all_notifications_raw(self, on_all_notifications_raw) -> None:
        """Callback for all notifications as dict."""
        self._on_all_notifications_raw = on_all_notifications_raw

    def get_active_hdmi_input_signal_notifications(
        self, on_active_hdmi_input_signal_notification
    ) -> None:
        """Callback for WebSocketEventActiveHdmiInputSignal notifications."""
        self._on_active_hdmi_input_signal_notification = (
            on_active_hdmi_input_signal_notification
        )

    def get_active_listening_mode_notifications(
        self, on_active_listening_mode_notification
    ) -> None:
        """Callback for WebSocketEventActiveListeningMode notifications."""
        self._on_active_listening_mode_notification = (
            on_active_listening_mode_notification
        )

    def get_active_speaker_group_notifications(
        self, on_active_speaker_group_notification
    ) -> None:
        """Callback for WebSocketEventActiveSpeakerGroup notifications."""
        self._on_active_speaker_group_notification = (
            on_active_speaker_group_notification
        )

    def get_alarm_timer_notifications(self, on_alarm_timer_notification) -> None:
        """Callback for WebSocketEventAlarmTimer notifications."""
        self._on_alarm_timer_notification = on_alarm_timer_notification

    def get_alarm_triggered_notifications(
        self, on_alarm_triggered_notification
    ) -> None:
        """Callback for WebSocketEventAlarmTriggered notifications."""
        self._on_alarm_triggered_notification = on_alarm_triggered_notification

    def get_battery_notifications(self, on_battery_notification) -> None:
        """Callback for WebSocketEventBattery notifications."""
        self._on_battery_notification = on_battery_notification

    def get_beo_remote_button_notifications(
        self, on_beo_remote_button_notification
    ) -> None:
        """Callback for WebSocketEventBeoRemoteButton notifications."""
        self._on_beo_remote_button_notification = on_beo_remote_button_notification

    def get_beolink_experiences_result_notifications(
        self, on_beolink_experiences_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkExperiencesResult notifications."""
        self._on_beolink_experiences_result_notification = (
            on_beolink_experiences_result_notification
        )

    def get_beolink_join_result_notifications(
        self, on_beolink_join_result_notification
    ) -> None:
        """Callback for WebSocketEventBeolinkJoinResult notifications."""
        self._on_beolink_join_result_notification = on_beolink_join_result_notification

    def get_button_notifications(self, on_button_notification) -> None:
        """Callback for WebSocketEventButton notifications."""
        self._on_button_notification = on_button_notification

    def get_curtains_notifications(self, on_curtains_notification) -> None:
        """Callback for WebSocketEventCurtains notifications."""
        self._on_curtains_notification = on_curtains_notification

    def get_hdmi_video_format_signal_notifications(
        self, on_hdmi_video_format_signal_notification
    ) -> None:
        """Callback for WebSocketEventHdmiVideoFormatSignal notifications."""
        self._on_hdmi_video_format_signal_notification = (
            on_hdmi_video_format_signal_notification
        )

    def get_notification_notifications(self, on_notification_notification) -> None:
        """Callback for WebSocketEventNotification notifications."""
        self._on_notification_notification = on_notification_notification

    def get_playback_error_notifications(self, on_playback_error_notification) -> None:
        """Callback for WebSocketEventPlaybackError notifications."""
        self._on_playback_error_notification = on_playback_error_notification

    def get_playback_metadata_notifications(
        self, on_playback_metadata_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackMetadata notifications."""
        self._on_playback_metadata_notification = on_playback_metadata_notification

    def get_playback_progress_notifications(
        self, on_playback_progress_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackProgress notifications."""
        self._on_playback_progress_notification = on_playback_progress_notification

    def get_playback_source_notifications(
        self, on_playback_source_notification
    ) -> None:
        """Callback for WebSocketEventPlaybackSource notifications."""
        self._on_playback_source_notification = on_playback_source_notification

    def get_playback_state_notifications(self, on_playback_state_notification) -> None:
        """Callback for WebSocketEventPlaybackState notifications."""
        self._on_playback_state_notification = on_playback_state_notification

    def get_power_state_notifications(self, on_power_state_notification) -> None:
        """Callback for WebSocketEventPowerState notifications."""
        self._on_power_state_notification = on_power_state_notification

    def get_puc_install_remote_id_status_notifications(
        self, on_puc_install_remote_id_status_notification
    ) -> None:
        """Callback for WebSocketEventPucInstallRemoteIdStatus notifications."""
        self._on_puc_install_remote_id_status_notification = (
            on_puc_install_remote_id_status_notification
        )

    def get_role_notifications(self, on_role_notification) -> None:
        """Callback for WebSocketEventRole notifications."""
        self._on_role_notification = on_role_notification

    def get_room_compensation_current_measurement_event_notifications(
        self, on_room_compensation_current_measurement_event_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationCurrentMeasurementEvent notifications."""
        self._on_room_compensation_current_measurement_event_notification = (
            on_room_compensation_current_measurement_event_notification
        )

    def get_room_compensation_state_notifications(
        self, on_room_compensation_state_notification
    ) -> None:
        """Callback for WebSocketEventRoomCompensationState notifications."""
        self._on_room_compensation_state_notification = (
            on_room_compensation_state_notification
        )

    def get_software_update_state_notifications(
        self, on_software_update_state_notification
    ) -> None:
        """Callback for WebSocketEventSoftwareUpdateState notifications."""
        self._on_software_update_state_notification = (
            on_software_update_state_notification
        )

    def get_sound_settings_notifications(self, on_sound_settings_notification) -> None:
        """Callback for WebSocketEventSoundSettings notifications."""
        self._on_sound_settings_notification = on_sound_settings_notification

    def get_source_change_notifications(self, on_source_change_notification) -> None:
        """Callback for WebSocketEventSourceChange notifications."""
        self._on_source_change_notification = on_source_change_notification

    def get_speaker_group_changed_notifications(
        self, on_speaker_group_changed_notification
    ) -> None:
        """Callback for WebSocketEventSpeakerGroupChanged notifications."""
        self._on_speaker_group_changed_notification = (
            on_speaker_group_changed_notification
        )

    def get_stand_connected_notifications(
        self, on_stand_connected_notification
    ) -> None:
        """Callback for WebSocketEventStandConnected notifications."""
        self._on_stand_connected_notification = on_stand_connected_notification

    def get_stand_position_notifications(self, on_stand_position_notification) -> None:
        """Callback for WebSocketEventStandPosition notifications."""
        self._on_stand_position_notification = on_stand_position_notification

    def get_tv_info_notifications(self, on_tv_info_notification) -> None:
        """Callback for WebSocketEventTvInfo notifications."""
        self._on_tv_info_notification = on_tv_info_notification

    def get_volume_notifications(self, on_volume_notification) -> None:
        """Callback for WebSocketEventVolume notifications."""
        self._on_volume_notification = on_volume_notification

    def get_wisa_out_state_notifications(self, on_wisa_out_state_notification) -> None:
        """Callback for WebSocketEventWisaOutState notifications."""
        self._on_wisa_out_state_notification = on_wisa_out_state_notification



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Literal, Optional

from mozart_api.models.tv_info_event_data import TvInfoEventData

from mozart_api.configuration import Configuration


class WebSocketEventTvInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"event_data": "TvInfoEventData", "event_type": "str"}

    attribute_map = {"event_data": "eventData", "event_type": "eventType"}

    def __init__(
        self,
        event_data: Optional[TvInfoEventData] = None,
        event_type: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """WebSocketEventTvInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._event_data = None
        self._event_type = None
        self.discriminator = None

        if event_data is not None:
            self.event_data = event_data
        if event_type is not None:
            self.event_type = event_type

    @property
    def event_data(self):
        # type: () -> TvInfoEventData
        """Gets the event_data of this WebSocketEventTvInfo.  # noqa: E501


        :return: The event_data of this WebSocketEventTvInfo.  # noqa: E501
        :rtype: TvInfoEventData
        """
        return self._event_data

    @event_data.setter
    def event_data(self, event_data):
        # type: (TvInfoEventData) -> None
        """Sets the event_data of this WebSocketEventTvInfo.


        :param event_data: The event_data of this WebSocketEventTvInfo.  # noqa: E501
        :type event_data: TvInfoEventData
        :rtype: None
        """

        self._event_data = event_data

    @property
    def event_type(self):
        # type: () -> str
        """Gets the event_type of this WebSocketEventTvInfo.  # noqa: E501


        :return: The event_type of this WebSocketEventTvInfo.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (str) -> None
        """Sets the event_type of this WebSocketEventTvInfo.


        :param event_type: The event_type of this WebSocketEventTvInfo.  # noqa: E501
        :type event_type: str
        :rtype: None
        """

        self._event_type = event_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebSocketEventTvInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WebSocketEventTvInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.compression import Compression  # noqa: E501
from mozart_api.rest import ApiException


class TestCompression(unittest.TestCase):
    """Compression unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Compression
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.compression.Compression()  # noqa: E501
        if include_optional:
            return Compression(value="off")
        else:
            return Compression(
                value="off",
            )

    def testCompression(self):
        """Test Compression"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Literal, Optional


from mozart_api.configuration import Configuration


class BatteryState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "battery_level": "int",
        "is_charging": "bool",
        "remaining_charging_time_minutes": "int",
        "remaining_playing_time_minutes": "int",
    }

    attribute_map = {
        "battery_level": "batteryLevel",
        "is_charging": "isCharging",
        "remaining_charging_time_minutes": "remainingChargingTimeMinutes",
        "remaining_playing_time_minutes": "remainingPlayingTimeMinutes",
    }

    def __init__(
        self,
        battery_level: Optional[int] = None,
        is_charging: Optional[bool] = None,
        remaining_charging_time_minutes: Optional[int] = None,
        remaining_playing_time_minutes: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """BatteryState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._battery_level = None
        self._is_charging = None
        self._remaining_charging_time_minutes = None
        self._remaining_playing_time_minutes = None
        self.discriminator = None

        if battery_level is not None:
            self.battery_level = battery_level
        if is_charging is not None:
            self.is_charging = is_charging
        if remaining_charging_time_minutes is not None:
            self.remaining_charging_time_minutes = remaining_charging_time_minutes
        if remaining_playing_time_minutes is not None:
            self.remaining_playing_time_minutes = remaining_playing_time_minutes

    @property
    def battery_level(self):
        # type: () -> int
        """Gets the battery_level of this BatteryState.  # noqa: E501

        Batterylevel in percent   # noqa: E501

        :return: The battery_level of this BatteryState.  # noqa: E501
        :rtype: int
        """
        return self._battery_level

    @battery_level.setter
    def battery_level(self, battery_level):
        # type: (int) -> None
        """Sets the battery_level of this BatteryState.

        Batterylevel in percent   # noqa: E501

        :param battery_level: The battery_level of this BatteryState.  # noqa: E501
        :type battery_level: int
        :rtype: None
        """

        self._battery_level = battery_level

    @property
    def is_charging(self):
        # type: () -> bool
        """Gets the is_charging of this BatteryState.  # noqa: E501


        :return: The is_charging of this BatteryState.  # noqa: E501
        :rtype: bool
        """
        return self._is_charging

    @is_charging.setter
    def is_charging(self, is_charging):
        # type: (bool) -> None
        """Sets the is_charging of this BatteryState.


        :param is_charging: The is_charging of this BatteryState.  # noqa: E501
        :type is_charging: bool
        :rtype: None
        """

        self._is_charging = is_charging

    @property
    def remaining_charging_time_minutes(self):
        # type: () -> int
        """Gets the remaining_charging_time_minutes of this BatteryState.  # noqa: E501

        Remaining charging time in minutes  # noqa: E501

        :return: The remaining_charging_time_minutes of this BatteryState.  # noqa: E501
        :rtype: int
        """
        return self._remaining_charging_time_minutes

    @remaining_charging_time_minutes.setter
    def remaining_charging_time_minutes(self, remaining_charging_time_minutes):
        # type: (int) -> None
        """Sets the remaining_charging_time_minutes of this BatteryState.

        Remaining charging time in minutes  # noqa: E501

        :param remaining_charging_time_minutes: The remaining_charging_time_minutes of this BatteryState.  # noqa: E501
        :type remaining_charging_time_minutes: int
        :rtype: None
        """

        self._remaining_charging_time_minutes = remaining_charging_time_minutes

    @property
    def remaining_playing_time_minutes(self):
        # type: () -> int
        """Gets the remaining_playing_time_minutes of this BatteryState.  # noqa: E501

        Remaining playing time in minutes  # noqa: E501

        :return: The remaining_playing_time_minutes of this BatteryState.  # noqa: E501
        :rtype: int
        """
        return self._remaining_playing_time_minutes

    @remaining_playing_time_minutes.setter
    def remaining_playing_time_minutes(self, remaining_playing_time_minutes):
        # type: (int) -> None
        """Sets the remaining_playing_time_minutes of this BatteryState.

        Remaining playing time in minutes  # noqa: E501

        :param remaining_playing_time_minutes: The remaining_playing_time_minutes of this BatteryState.  # noqa: E501
        :type remaining_playing_time_minutes: int
        :rtype: None
        """

        self._remaining_playing_time_minutes = remaining_playing_time_minutes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatteryState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatteryState):
            return True

        return self.to_dict() != other.to_dict()
